@@ -25,7 +25,7 @@ def _assign_cell(latitude, longitude, cell_size=0.2) -> int:
     return cell_number
 
 
-def detect_home_work(legs, waypoints) -> tuple(tuple(float, float), tuple(float, float)):
+def detect_home_work(legs, waypoints):# -> tuple(tuple(float, float), tuple(float, float)):
     """Detects home and work locations, tags them with 'Home' or 'Work' in the df
 
     Args:
