@@ -4,7 +4,7 @@ from datetime import datetime, timedelta
 import pandas as pd
 pd.options.mode.chained_assignment = None
 
-def add_noise(point, radius=100, offset=30) -> tuple(float, float):
+def add_noise(point, radius=100, offset=30):# -> tuple(float, float):
     """Adds random uniform noise to the given point, in a radius = radius - offset
 
     Args:
@@ -28,7 +28,7 @@ def add_noise(point, radius=100, offset=30) -> tuple(float, float):
     
     return shift_point(point, latitude_shift_km, longitude_shift_km)
 
-def shift_point(point, latitude_shift_km, longitude_shift_km) -> tuple(float, float):
+def shift_point(point, latitude_shift_km, longitude_shift_km):# -> tuple(float, float):
     """Shifts the coordinates of a given point.
 
     Args:
@@ -96,7 +96,7 @@ def km_to_lat(km_north) -> float:
     """
     return km_north/110.574
 
-def assign_cell_center(latitude, longitude, cell_size) -> tuple(float, float):
+def assign_cell_center(latitude, longitude, cell_size):# -> tuple(float, float):
     """Returns the closest cell center for the given coordinates, when the map is divided into a lattice with the supplied cell_size
 
     Args:
